@@ -21,7 +21,7 @@ from ldap3 import ALL_ATTRIBUTES, BASE
 from pyramid.decorator import reify
 from zope.interface import Interface, implementer
 
-from pyams_auth_ldap.interfaces import ILDAPPlugin
+from pyams_auth_ldap.interfaces import ILDAPPlugin, LDAP_PLUGIN_LABEL
 from pyams_auth_ldap.query import LDAPQuery
 from pyams_form.ajax import ajax_form_config
 from pyams_form.browser.checkbox import SingleCheckBoxFieldWidget
@@ -32,14 +32,14 @@ from pyams_layer.interfaces import IPyAMSLayer
 from pyams_pagelet.pagelet import pagelet_config
 from pyams_security.interfaces import IPlugin, ISecurityManager
 from pyams_security.interfaces.base import MANAGE_SECURITY_PERMISSION
-from pyams_security_views.zmi import ISecurityManagerView
-from pyams_security_views.zmi.plugin import SecurityPluginAddForm, SecurityPluginAddMenu, \
-    SecurityPluginPropertiesEditForm
-from pyams_site.interfaces import ISiteRoot
+from pyams_security_views.zmi import SecurityPluginsTable
+from pyams_security_views.zmi.plugin import InnerSecurityPluginFormMixin, SecurityPluginAddForm, \
+    SecurityPluginAddMenu, SecurityPluginPropertiesEditForm
 from pyams_skin.interfaces.viewlet import IContentSuffixViewletManager
 from pyams_table.column import GetAttrColumn
 from pyams_table.interfaces import IColumn, IValues
 from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
+from pyams_utils.registry import get_utility
 from pyams_utils.url import absolute_url
 from pyams_viewlet.viewlet import viewlet_config
 from pyams_zmi.form import AdminModalDisplayForm
@@ -59,9 +59,10 @@ from pyams_auth_ldap import _  # pylint: disable=ungrouped-imports
 # LDAP plug-in add form
 #
 
+
 @viewlet_config(name='add-ldap-plugin.menu',
-                context=ISiteRoot, layer=IAdminLayer, view=ISecurityManagerView,
-                manager=IContextAddingsViewletManager, weight=45,
+                context=ISecurityManager, layer=IAdminLayer, view=SecurityPluginsTable,
+                manager=IContextAddingsViewletManager, weight=40,
                 permission=MANAGE_SECURITY_PERMISSION)
 class LDAPPluginAddMenu(SecurityPluginAddMenu):
     """LDAP plug-in add menu"""
@@ -76,8 +77,8 @@ class LDAPPluginAddMenu(SecurityPluginAddMenu):
 class LDAPPluginAddForm(SecurityPluginAddForm):
     """LDAP plug-in add form"""
 
-    legend = _("Add LDAP directory plug-in")
     content_factory = ILDAPPlugin
+    content_label = LDAP_PLUGIN_LABEL
 
     fields = Fields(IPlugin).omit('__parent__', '__name__')
     fields['enabled'].widget_factory = SingleCheckBoxFieldWidget
@@ -148,8 +149,6 @@ class LDAPPluginSearchSettingsAddForm(InnerAddForm):
 class LDAPPluginPropertiesEditForm(SecurityPluginPropertiesEditForm):
     """LDAP plug-in properties edit form"""
 
-    title = _("LDAP directory plug-in")
-
 
 @adapter_config(name='connection',
                 required=(ILDAPPlugin, IAdminLayer, LDAPPluginPropertiesEditForm),
@@ -220,7 +219,8 @@ class LDAPPluginSearchForm(SearchForm):  # pylint: disable=abstract-method
     @property
     def back_url(self):
         """Form back URL getter"""
-        return absolute_url(self.request.root, self.request, 'security-plugins.html')
+        manager = get_utility(ISecurityManager)
+        return absolute_url(manager, self.request, 'security-plugins.html')
 
 
 @pagelet_config(name='search.html', context=ILDAPPlugin, layer=IPyAMSLayer,
@@ -321,13 +321,15 @@ class LDAPPluginSearchResultsView(SearchResultsView):
 
 @pagelet_config(name='ldap-properties.html', context=ILDAPPlugin, layer=IPyAMSLayer,
                 permission=MANAGE_SECURITY_PERMISSION)
-class LDAPEntryPropertiesDisplayForm(AdminModalDisplayForm):
+class LDAPEntryPropertiesDisplayForm(InnerSecurityPluginFormMixin, AdminModalDisplayForm):
     """LDAP entry properties display form"""
 
     @property
     def title(self):
         """Form title getter"""
-        return 'DN: {}'.format(self.ldap_entry.get('dn', _('unknown')))
+        return '{}<br /><small>DN: {}</small>'.format(
+            super().title,
+            self.ldap_entry.get('dn', _('unknown')))
 
     legend = _("LDAP entry attributes")
     fields = Fields(Interface)
@@ -398,4 +400,4 @@ class LDAPEntryValuesColumn(I18nColumnMixin, GetAttrColumn):
     weight = 20
 
     def get_value(self, obj):
-        return '<br />'.join(obj[1])
+        return '<br />'.join(obj[1] if isinstance(obj[1], (list, tuple)) else {obj[1]})
